@@ -42,7 +42,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.533';
+our $VERSION = '1.534';
 $VERSION = eval $VERSION;
 
 use MIME::Parser;
@@ -1068,7 +1068,8 @@ sub _std_reason {
 	/bulk\s+e?mail/i or
 	/probably\s+spam/i or
 	/appears\s+to\s+be\s+SPAM/i or
-         /SPAM NOT ACCEPTED/i
+    /SPAM NOT ACCEPTED/i or
+	/5.9.8\s+spam/i
   ) {
     return "spam";
   }
